@@ -48,7 +48,7 @@ graph_version <- function(graph) {
 
   } else {
     stopifnot(is_igraph(graph))
-    .Call("R_igraph_graph_version", graph, PACKAGE = "igraph")
+    .Call(C_R_igraph_graph_version, graph)
   }
 }
 
@@ -82,10 +82,10 @@ upgrade_graph <- function(graph) {
   if (g_ver < p_ver) {
 
     if ((g_ver == "0.4.0" && p_ver == "0.8.0")) {
-      .Call("R_igraph_add_env", graph, PACKAGE = "igraph")
+      .Call(C_R_igraph_add_env, graph)
 
     } else if (g_ver == "0.7.999" && p_ver == "0.8.0") {
-      .Call("R_igraph_add_version_to_env", graph, PACKAGE = "igraph")
+      .Call(C_R_igraph_add_version_to_env, graph)
 
     } else {
       stop("Don't know how to upgrade graph from ", g_ver, " to ", p_ver)
