@@ -2,7 +2,7 @@
 /*
  * This file contains the clique searching routines.
  *
- * Copyright (C) 2002 Sampo Niskanen, Patric stergrd.
+ * Copyright (C) 2002 Sampo Niskanen, Patric Östergård.
  * Licensed under the GNU GPL, read the file LICENSE for details.
  */
 
@@ -842,8 +842,9 @@ static int sub_weighted_all(int *table, int size, int weight,
 		/* current_weight < min_weight, prune_low < min_weight,
 		 * so return value is always < min_weight. */
 		if (current_weight>prune_low) {
-			if (best_clique)
-				set_copy(best_clique,current_clique);
+			if (best_clique) {
+				best_clique = set_copy(best_clique,current_clique);
+			}
 			if (current_weight < min_weight)
 				return current_weight;
 			else
@@ -949,7 +950,7 @@ static boolean store_clique(set_t clique, graph_t *g, clique_options *opts) {
 		}
 		if (clique_list_count <= opts->clique_list_length)
 			opts->clique_list[clique_list_count-1] =
-				set_duplicate(clique);
+				set_copy(opts->clique_list[clique_list_count-1], clique);
 	}
 
 	/* user_function() */
