@@ -133,7 +133,8 @@ int igraph_ncol_yyerror(YYLTYPE* locp,
 			igraph_i_ncol_parsedata_t *context, 
 			const char *s);
 char *igraph_ncol_yyget_text (yyscan_t yyscanner );
-int igraph_ncol_yyget_leng (yyscan_t yyscanner );
+typedef size_t yy_size_t;
+yy_size_t igraph_ncol_yyget_leng (yyscan_t yyscanner );
 igraph_real_t igraph_ncol_get_number(const char *str, long int len);
 
 #define scanner context->scanner
