@@ -8,7 +8,7 @@ test_that("complementer works", {
   g <- sample_gnp(50, 3/50)
   g2 <- complementer(g)
   g3 <- complementer(g2)
-  expect_that(graph.isomorphic(g, g3), is_true())
+  expect_true(graph.isomorphic(g, g3))
   
 })
 
